"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MsgClientImpl = void 0;
const binary_1 = require("../../../binary");
const tx_1 = require("./tx");
class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Send defines a method for sending coins from one account to another account. */
    send = async (request) => {
        const data = tx_1.MsgSend.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Msg", "Send", data);
        return promise.then(data => tx_1.MsgSendResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* MultiSend defines a method for sending coins from some accounts to other accounts. */
    multiSend = async (request) => {
        const data = tx_1.MsgMultiSend.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Msg", "MultiSend", data);
        return promise.then(data => tx_1.MsgMultiSendResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* Burn defines a method for burning coins by an account.
    
     Since: cosmos-sdk 0.51 */
    burn = async (request) => {
        const data = tx_1.MsgBurn.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Msg", "Burn", data);
        return promise.then(data => tx_1.MsgBurnResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* UpdateParams defines a governance operation for updating the x/bank module parameters.
     The authority is defined in the keeper.
    
     Since: cosmos-sdk 0.47 */
    updateParams = async (request) => {
        const data = tx_1.MsgUpdateParams.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Msg", "UpdateParams", data);
        return promise.then(data => tx_1.MsgUpdateParamsResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* SetSendEnabled is a governance operation for setting the SendEnabled flag
     on any number of Denoms. Only the entries to add or update should be
     included. Entries that already exist in the store, but that aren't
     included in this message, will be left unchanged.
    
     Since: cosmos-sdk 0.47 */
    setSendEnabled = async (request) => {
        const data = tx_1.MsgSetSendEnabled.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Msg", "SetSendEnabled", data);
        return promise.then(data => tx_1.MsgSetSendEnabledResponse.decode(new binary_1.BinaryReader(data)));
    };
}
exports.MsgClientImpl = MsgClientImpl;
//# sourceMappingURL=tx.rpc.msg.js.map