"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LCDQueryClient = void 0;
const helpers_1 = require("../../../helpers");
class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* GroupInfo queries group info based on group id. */
    groupInfo = async (params) => {
        const endpoint = `cosmos/group/v1/group_info/${params.groupId}`;
        return await this.req.get(endpoint);
    };
    /* GroupPolicyInfo queries group policy info based on account address of group policy. */
    groupPolicyInfo = async (params) => {
        const endpoint = `cosmos/group/v1/group_policy_info/${params.address}`;
        return await this.req.get(endpoint);
    };
    /* GroupMembers queries members of a group by group id. */
    groupMembers = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/group_members/${params.groupId}`;
        return await this.req.get(endpoint, options);
    };
    /* GroupsByAdmin queries groups by admin address. */
    groupsByAdmin = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/groups_by_admin/${params.admin}`;
        return await this.req.get(endpoint, options);
    };
    /* GroupPoliciesByGroup queries group policies by group id. */
    groupPoliciesByGroup = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/group_policies_by_group/${params.groupId}`;
        return await this.req.get(endpoint, options);
    };
    /* GroupPoliciesByAdmin queries group policies by admin address. */
    groupPoliciesByAdmin = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/group_policies_by_admin/${params.admin}`;
        return await this.req.get(endpoint, options);
    };
    /* Proposal queries a proposal based on proposal id. */
    proposal = async (params) => {
        const endpoint = `cosmos/group/v1/proposal/${params.proposalId}`;
        return await this.req.get(endpoint);
    };
    /* ProposalsByGroupPolicy queries proposals based on account address of group policy. */
    proposalsByGroupPolicy = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/proposals_by_group_policy/${params.address}`;
        return await this.req.get(endpoint, options);
    };
    /* VoteByProposalVoter queries a vote by proposal id and voter. */
    voteByProposalVoter = async (params) => {
        const endpoint = `cosmos/group/v1/vote_by_proposal_voter/${params.proposalId}/${params.voter}`;
        return await this.req.get(endpoint);
    };
    /* VotesByProposal queries a vote by proposal id. */
    votesByProposal = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/votes_by_proposal/${params.proposalId}`;
        return await this.req.get(endpoint, options);
    };
    /* VotesByVoter queries a vote by voter. */
    votesByVoter = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/votes_by_voter/${params.voter}`;
        return await this.req.get(endpoint, options);
    };
    /* GroupsByMember queries groups by member address. */
    groupsByMember = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/groups_by_member/${params.address}`;
        return await this.req.get(endpoint, options);
    };
    /* TallyResult returns the tally result of a proposal. If the proposal is
     still in voting period, then this query computes the current tally state,
     which might not be final. On the other hand, if the proposal is final,
     then it simply returns the `final_tally_result` state stored in the
     proposal itself. */
    tallyResult = async (params) => {
        const endpoint = `cosmos/group/v1/proposals/${params.proposalId}/tally`;
        return await this.req.get(endpoint);
    };
    /* Groups queries all groups in state.
    
     Since: cosmos-sdk 0.47.1 */
    groups = async (params = {
        pagination: undefined
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            (0, helpers_1.setPaginationParams)(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/groups`;
        return await this.req.get(endpoint, options);
    };
}
exports.LCDQueryClient = LCDQueryClient;
//# sourceMappingURL=query.lcd.js.map